@@ -21,8 +21,10 @@ use OCP\Files\SimpleFS\ISimpleFile;
 use OCP\IBinaryFinder;
 use OCP\IConfig;
 use OCP\IPreview;
-use OCP\IServerContainer;
 use OCP\Preview\IProviderV2;
+use Psr\Container\ContainerInterface;
+use Psr\Log\LoggerInterface;
+
 use function array_key_exists;
 
 class PreviewManager implements IPreview {
@@ -47,22 +49,22 @@ class PreviewManager implements IPreview {
 	 * @psalm-var array<string, null>
 	 */
 	private array $loadedBootstrapProviders = [];
-	private IServerContainer $container;
+	private ContainerInterface $container;
 	private IBinaryFinder $binaryFinder;
 	private IMagickSupport $imagickSupport;
 	private bool $enablePreviews;
 
 	public function __construct(
-		IConfig                  $config,
-		IRootFolder              $rootFolder,
-		IAppData                 $appData,
-		IEventDispatcher 		 $eventDispatcher,
-		GeneratorHelper          $helper,
-		?string                  $userId,
-		Coordinator              $bootstrapCoordinator,
-		IServerContainer         $container,
-		IBinaryFinder            $binaryFinder,
-		IMagickSupport           $imagickSupport
+		IConfig $config,
+		IRootFolder $rootFolder,
+		IAppData $appData,
+		IEventDispatcher $eventDispatcher,
+		GeneratorHelper $helper,
+		?string $userId,
+		Coordinator $bootstrapCoordinator,
+		ContainerInterface $container,
+		IBinaryFinder $binaryFinder,
+		IMagickSupport $imagickSupport,
 	) {
 		$this->config = $config;
 		$this->rootFolder = $rootFolder;
@@ -136,35 +138,27 @@ class PreviewManager implements IPreview {
 					$this->rootFolder,
 					$this->config
 				),
-				$this->eventDispatcher
+				$this->eventDispatcher,
+				$this->container->get(LoggerInterface::class),
 			);
 		}
 		return $this->generator;
 	}
 
-	/**
-	 * Returns a preview of a file
-	 *
-	 * The cache is searched first and if nothing usable was found then a preview is
-	 * generated by one of the providers
-	 *
-	 * @param File $file
-	 * @param int $width
-	 * @param int $height
-	 * @param bool $crop
-	 * @param string $mode
-	 * @param string $mimeType
-	 * @return ISimpleFile
-	 * @throws NotFoundException
-	 * @throws \InvalidArgumentException if the preview would be invalid (in case the original image is invalid)
-	 * @since 11.0.0 - \InvalidArgumentException was added in 12.0.0
-	 */
-	public function getPreview(File $file, $width = -1, $height = -1, $crop = false, $mode = IPreview::MODE_FILL, $mimeType = null) {
+	public function getPreview(
+		File $file,
+		$width = -1,
+		$height = -1,
+		$crop = false,
+		$mode = IPreview::MODE_FILL,
+		$mimeType = null,
+		bool $cacheResult = true,
+	): ISimpleFile {
 		$this->throwIfPreviewsDisabled();
 		$previewConcurrency = $this->getGenerator()->getNumConcurrentPreviews('preview_concurrency_all');
 		$sem = Generator::guardWithSemaphore(Generator::SEMAPHORE_ID_ALL, $previewConcurrency);
 		try {
-			$preview = $this->getGenerator()->getPreview($file, $width, $height, $crop, $mode, $mimeType);
+			$preview = $this->getGenerator()->getPreview($file, $width, $height, $crop, $mode, $mimeType, $cacheResult);
 		} finally {
 			Generator::unguardWithSemaphore($sem);
 		}
@@ -343,7 +337,7 @@ class PreviewManager implements IPreview {
 		$this->registerCoreProvider(Preview\XBitmap::class, '/image\/x-xbitmap/');
 		$this->registerCoreProvider(Preview\WebP::class, '/image\/webp/');
 		$this->registerCoreProvider(Preview\Krita::class, '/application\/x-krita/');
-		$this->registerCoreProvider(Preview\MP3::class, '/audio\/mpeg/');
+		$this->registerCoreProvider(Preview\MP3::class, '/audio\/mpeg$/');
 		$this->registerCoreProvider(Preview\OpenDocument::class, '/application\/vnd.oasis.opendocument.*/');
 		$this->registerCoreProvider(Preview\Imaginary::class, Preview\Imaginary::supportedMimeTypes());
 		$this->registerCoreProvider(Preview\ImaginaryPDF::class, Preview\ImaginaryPDF::supportedMimeTypes());
@@ -389,7 +383,7 @@ class PreviewManager implements IPreview {
 
 
 			if (is_string($movieBinary)) {
-				$this->registerCoreProvider(Preview\Movie::class, '/video\/.*/', ["movieBinary" => $movieBinary]);
+				$this->registerCoreProvider(Preview\Movie::class, '/video\/.*/', ['movieBinary' => $movieBinary]);
 			}
 		}
 	}
